==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/networkcloud/kotlin/outputs/GetL3NetworkResult.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.networkcloud.kotlin.outputs

import kotlin.Double
import kotlin.String
import kotlin.Suppress
import kotlin.collections.List
import kotlin.collections.Map

/**
 *
 * @property associatedResourceIds The list of resource IDs for the other Microsoft.NetworkCloud resources that have attached this network.
 * @property clusterId The resource ID of the Network Cloud cluster this L3 network is associated with.
 * @property detailedStatus The more detailed status of the L3 network.
 * @property detailedStatusMessage The descriptive message about the current detailed status.
 * @property extendedLocation The extended location of the cluster associated with the resource.
 * @property hybridAksClustersAssociatedIds Field Deprecated. These fields will be empty/omitted. The list of Hybrid AKS cluster resource IDs that are associated with this L3 network.
 * @property hybridAksIpamEnabled Field Deprecated. The field was previously optional, now it will have no defined behavior and will be ignored. The indicator of whether or not to disable IPAM allocation on the network attachment definition injected into the Hybrid AKS Cluster.
 * @property hybridAksPluginType Field Deprecated. The field was previously optional, now it will have no defined behavior and will be ignored. The network plugin type for Hybrid AKS.
 * @property id Fully qualified resource ID for the resource. E.g. "/subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/{resourceProviderNamespace}/{resourceType}/{resourceName}"
 * @property interfaceName The default interface name for this L3 network in the virtual machine. This name can be overridden by the name supplied in the network attachment configuration of that virtual machine.
 * @property ipAllocationType The type of the IP address allocation, defaulted to "DualStack".
 * @property ipv4ConnectedPrefix The IPV4 prefix (CIDR) assigned to this L3 network. Required when the IP allocation type
 * is IPV4 or DualStack.
 * @property ipv6ConnectedPrefix The IPV6 prefix (CIDR) assigned to this L3 network. Required when the IP allocation type
 * is IPV6 or DualStack.
 * @property l3IsolationDomainId The resource ID of the Network Fabric l3IsolationDomain.
 * @property location The geo-location where the resource lives
 * @property name The name of the resource
 * @property provisioningState The provisioning state of the L3 network.
 * @property systemData Azure Resource Manager metadata containing createdBy and modifiedBy information.
 * @property tags Resource tags.
 * @property type The type of the resource. E.g. "Microsoft.Compute/virtualMachines" or "Microsoft.Storage/storageAccounts"
 * @property virtualMachinesAssociatedIds Field Deprecated. These fields will be empty/omitted. The list of virtual machine resource IDs, excluding any Hybrid AKS virtual machines, that are currently using this L3 network.
 * @property vlan The VLAN from the l3IsolationDomain that is used for this network.
 */
public data class GetL3NetworkResult(
    public val associatedResourceIds: List<String>,
    public val clusterId: String,
    public val detailedStatus: String,
    public val detailedStatusMessage: String,
    public val extendedLocation: ExtendedLocationResponse,
    public val hybridAksClustersAssociatedIds: List<String>,
    public val hybridAksIpamEnabled: String? = null,
    public val hybridAksPluginType: String? = null,
    public val id: String,
    public val interfaceName: String? = null,
    public val ipAllocationType: String? = null,
    public val ipv4ConnectedPrefix: String? = null,
    public val ipv6ConnectedPrefix: String? = null,
    public val l3IsolationDomainId: String,
    public val location: String,
    public val name: String,
    public val provisioningState: String,
    public val systemData: SystemDataResponse,
    public val tags: Map<String, String>? = null,
    public val type: String,
    public val virtualMachinesAssociatedIds: List<String>,
    public val vlan: Double,
) {
    public companion object {
        public fun toKotlin(javaType: com.pulumi.azurenative.networkcloud.outputs.GetL3NetworkResult):
            GetL3NetworkResult = GetL3NetworkResult(
            associatedResourceIds = javaType.associatedResourceIds().map({ args0 -> args0 }),
            clusterId = javaType.clusterId(),
            detailedStatus = javaType.detailedStatus(),
            detailedStatusMessage = javaType.detailedStatusMessage(),
            extendedLocation = javaType.extendedLocation().let({ args0 ->
                com.pulumi.azurenative.networkcloud.kotlin.outputs.ExtendedLocationResponse.Companion.toKotlin(args0)
            }),
            hybridAksClustersAssociatedIds = javaType.hybridAksClustersAssociatedIds().map({ args0 -> args0 }),
            hybridAksIpamEnabled = javaType.hybridAksIpamEnabled().map({ args0 -> args0 }).orElse(null),
            hybridAksPluginType = javaType.hybridAksPluginType().map({ args0 -> args0 }).orElse(null),
            id = javaType.id(),
            interfaceName = javaType.interfaceName().map({ args0 -> args0 }).orElse(null),
            ipAllocationType = javaType.ipAllocationType().map({ args0 -> args0 }).orElse(null),
            ipv4ConnectedPrefix = javaType.ipv4ConnectedPrefix().map({ args0 -> args0 }).orElse(null),
            ipv6ConnectedPrefix = javaType.ipv6ConnectedPrefix().map({ args0 -> args0 }).orElse(null),
            l3IsolationDomainId = javaType.l3IsolationDomainId(),
            location = javaType.location(),
            name = javaType.name(),
            provisioningState = javaType.provisioningState(),
            systemData = javaType.systemData().let({ args0 ->
                com.pulumi.azurenative.networkcloud.kotlin.outputs.SystemDataResponse.Companion.toKotlin(args0)
            }),
            tags = javaType.tags().map({ args0 -> args0.key.to(args0.value) }).toMap(),
            type = javaType.type(),
            virtualMachinesAssociatedIds = javaType.virtualMachinesAssociatedIds().map({ args0 -> args0 }),
            vlan = javaType.vlan(),
        )
    }
}

==> pulumi-azure-native-kotlin-2.44.1.0-sources.jar: com/pulumi/azurenative/networkcloud/kotlin/outputs/GetL3NetworkResult.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.networkcloud.kotlin.outputs

import kotlin.Double
import kotlin.String
import kotlin.Suppress
import kotlin.collections.List
import kotlin.collections.Map

/**
 *
 * @property associatedResourceIds The list of resource IDs for the other Microsoft.NetworkCloud resources that have attached this network.
 * @property clusterId The resource ID of the Network Cloud cluster this L3 network is associated with.
 * @property detailedStatus The more detailed status of the L3 network.
 * @property detailedStatusMessage The descriptive message about the current detailed status.
 * @property extendedLocation The extended location of the cluster associated with the resource.
 * @property hybridAksClustersAssociatedIds Field Deprecated. These fields will be empty/omitted. The list of Hybrid AKS cluster resource IDs that are associated with this L3 network.
 * @property hybridAksIpamEnabled Field Deprecated. The field was previously optional, now it will have no defined behavior and will be ignored. The indicator of whether or not to disable IPAM allocation on the network attachment definition injected into the Hybrid AKS Cluster.
 * @property hybridAksPluginType Field Deprecated. The field was previously optional, now it will have no defined behavior and will be ignored. The network plugin type for Hybrid AKS.
 * @property id Fully qualified resource ID for the resource. E.g. "/subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/{resourceProviderNamespace}/{resourceType}/{resourceName}"
 * @property interfaceName The default interface name for this L3 network in the virtual machine. This name can be overridden by the name supplied in the network attachment configuration of that virtual machine.
 * @property ipAllocationType The type of the IP address allocation, defaulted to "DualStack".
 * @property ipv4ConnectedPrefix The IPV4 prefix (CIDR) assigned to this L3 network. Required when the IP allocation type
 * is IPV4 or DualStack.
 * @property ipv6ConnectedPrefix The IPV6 prefix (CIDR) assigned to this L3 network. Required when the IP allocation type
 * is IPV6 or DualStack.
 * @property l3IsolationDomainId The resource ID of the Network Fabric l3IsolationDomain.
 * @property location The geo-location where the resource lives
 * @property name The name of the resource
 * @property provisioningState The provisioning state of the L3 network.
 * @property systemData Azure Resource Manager metadata containing createdBy and modifiedBy information.
 * @property tags Resource tags.
 * @property type The type of the resource. E.g. "Microsoft.Compute/virtualMachines" or "Microsoft.Storage/storageAccounts"
 * @property virtualMachinesAssociatedIds Field Deprecated. These fields will be empty/omitted. The list of virtual machine resource IDs, excluding any Hybrid AKS virtual machines, that are currently using this L3 network.
 * @property vlan The VLAN from the l3IsolationDomain that is used for this network.
 */
public data class GetL3NetworkResult(
    public val associatedResourceIds: List<String>,
    public val clusterId: String,
    public val detailedStatus: String,
    public val detailedStatusMessage: String,
    public val extendedLocation: ExtendedLocationResponse,
    public val hybridAksClustersAssociatedIds: List<String>,
    public val hybridAksIpamEnabled: String? = null,
    public val hybridAksPluginType: String? = null,
    public val id: String,
    public val interfaceName: String? = null,
    public val ipAllocationType: String? = null,
    public val ipv4ConnectedPrefix: String? = null,
    public val ipv6ConnectedPrefix: String? = null,
    public val l3IsolationDomainId: String,
    public val location: String,
    public val name: String,
    public val provisioningState: String,
    public val systemData: SystemDataResponse,
    public val tags: Map<String, String>? = null,
    public val type: String,
    public val virtualMachinesAssociatedIds: List<String>,
    public val vlan: Double,
) {
    public companion object {
        public fun toKotlin(javaType: com.pulumi.azurenative.networkcloud.outputs.GetL3NetworkResult): GetL3NetworkResult = GetL3NetworkResult(
            associatedResourceIds = javaType.associatedResourceIds().map({ args0 -> args0 }),
            clusterId = javaType.clusterId(),
            detailedStatus = javaType.detailedStatus(),
            detailedStatusMessage = javaType.detailedStatusMessage(),
            extendedLocation = javaType.extendedLocation().let({ args0 ->
                com.pulumi.azurenative.networkcloud.kotlin.outputs.ExtendedLocationResponse.Companion.toKotlin(args0)
            }),
            hybridAksClustersAssociatedIds = javaType.hybridAksClustersAssociatedIds().map({ args0 -> args0 }),
            hybridAksIpamEnabled = javaType.hybridAksIpamEnabled().map({ args0 -> args0 }).orElse(null),
            hybridAksPluginType = javaType.hybridAksPluginType().map({ args0 -> args0 }).orElse(null),
            id = javaType.id(),
            interfaceName = javaType.interfaceName().map({ args0 -> args0 }).orElse(null),
            ipAllocationType = javaType.ipAllocationType().map({ args0 -> args0 }).orElse(null),
            ipv4ConnectedPrefix = javaType.ipv4ConnectedPrefix().map({ args0 -> args0 }).orElse(null),
            ipv6ConnectedPrefix = javaType.ipv6ConnectedPrefix().map({ args0 -> args0 }).orElse(null),
            l3IsolationDomainId = javaType.l3IsolationDomainId(),
            location = javaType.location(),
            name = javaType.name(),
            provisioningState = javaType.provisioningState(),
            systemData = javaType.systemData().let({ args0 ->
                com.pulumi.azurenative.networkcloud.kotlin.outputs.SystemDataResponse.Companion.toKotlin(args0)
            }),
            tags = javaType.tags().map({ args0 -> args0.key.to(args0.value) }).toMap(),
            type = javaType.type(),
            virtualMachinesAssociatedIds = javaType.virtualMachinesAssociatedIds().map({ args0 -> args0 }),
            vlan = javaType.vlan(),
        )
    }
}
